pub enum Error {
Configuration(String),
Parse(Option<Location>, String),
Internal(Option<Location>, String),
TestFailure(Option<Location>, String),
}Expand description
Errors produced by the json5format library.
Variants
Configuration(String)
A formatter configuration option was invalid.
Parse(Option<Location>, String)
A syntax error was encountered while parsing a JSON5 document.
Internal(Option<Location>, String)
The parser or formatter entered an unexpected state. An Error::Internal likely indicates
there is a software bug in the json5format library.
TestFailure(Option<Location>, String)
This error is only produced by internal test functions to indicate a test result did not match expectations.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn configuration(err: impl Display) -> Self
pub fn configuration(err: impl Display) -> Self
Sourcepub fn parse(location: Option<Location>, err: impl Display) -> Self
pub fn parse(location: Option<Location>, err: impl Display) -> Self
Return a parsing error.
Arguments
- location - Optional location in the JSON5 document where the error was detected.
- err - The error message.
Sourcepub fn internal(location: Option<Location>, err: impl Into<String>) -> Self
pub fn internal(location: Option<Location>, err: impl Into<String>) -> Self
Return an internal error (indicating an error in the software implementation itself).
Arguments
- location - Optional location in the JSON5 document where the error was detected, which might be available if the error occurred while parsing the document.
- err - The error message.